@@ -123,6 +123,7 @@ class DBAPICursor(with_metaclass(abc.ABCMeta, object)):
         An :py:class:`~pyhive.exc.Error` (or subclass) exception is raised if the previous call to
         :py:meth:`execute` did not produce any result set or no call was issued yet.
         """
+        _logger.info("Commons - fetch many")
         if size is None:
             size = self.arraysize
         return list(islice(iter(self.fetchone, None), size))
@@ -133,6 +134,7 @@ class DBAPICursor(with_metaclass(abc.ABCMeta, object)):
         An :py:class:`~pyhive.exc.Error` (or subclass) exception is raised if the previous call to
         :py:meth:`execute` did not produce any result set or no call was issued yet.
         """
+        _logger.info("Commons - fetch all")
         return list(iter(self.fetchone, None))
 
     @property
@@ -172,6 +174,7 @@ class DBAPICursor(with_metaclass(abc.ABCMeta, object)):
         as :py:meth:`fetchone`. A ``StopIteration`` exception is raised when the result set is
         exhausted.
         """
+        _logger.info("Commons - fetching the next row")
         one = self.fetchone()
         if one is None:
             raise StopIteration
